@@ -13,13 +13,14 @@ import struct
 import tarfile
 import zipfile
 import zlib
-from typing import IO, TYPE_CHECKING, Any, TextIO, cast
+from typing import IO, TYPE_CHECKING, Any, BinaryIO, Optional, TextIO, cast
 
 import regex as re
 from lxml import etree
 
 import arelle.PluginManager
 from arelle import PackageManager, XmlUtil
+from arelle.PythonUtil import isLegacyAbs
 from arelle.packages.report.DetectReportPackage import isReportPackageExtension
 from arelle.packages.report.ReportPackage import ReportPackage
 from arelle.typing import TypeGetText
@@ -43,15 +44,17 @@ TAXONOMY_PACKAGE_FILE_NAMES = ('.taxonomyPackage.xml', 'catalog.xml') # pre-PWD
 def openFileSource(
     filename: str | None,
     cntlr: Cntlr | None = None,
-    sourceZipStream: str | None = None,
+    sourceZipStream: BinaryIO | FileNamedBytesIO | None = None,
     checkIfXmlIsEis: bool = False,
     reloadCache: bool = False,
     base: str | None = None,
     sourceFileSource: FileSource | None = None,
-    sourceZipStreamFileName: str | None = None,
 ) -> FileSource:
     if sourceZipStream:
-        sourceZipStreamFileName = os.sep + (sourceZipStreamFileName or "POSTupload.zip")
+        if isinstance(sourceZipStream, FileNamedBytesIO) and sourceZipStream.fileName:
+            sourceZipStreamFileName = os.sep + sourceZipStream.fileName
+        else:
+            sourceZipStreamFileName = os.sep + "POSTupload.zip"
         filesource = FileSource(sourceZipStreamFileName, cntlr)
         filesource.openZipStream(sourceZipStream)
         if filename:
@@ -190,7 +193,11 @@ class FileSource:
         if not self.isZip:
             # Try to detect zip files with unrecognized file extensions.
             try:
-                basefile = self.cntlr.webCache.getfilename(self.url) if self.cntlr is not None else self.url
+                if self.cntlr is not None and hasattr(self.cntlr, "modelManager"):
+                    basefile = self.cntlr.webCache.getfilename( # cache remapping
+                        self.cntlr.modelManager.disclosureSystem.mappedUrl(self.url)) # local remapping
+                else:
+                    basefile = self.url
                 if basefile:
                     with openFileStream(self.cntlr, basefile, 'rb') as fileStream:
                         self.isZip = zipfile.is_zipfile(fileStream)
@@ -212,7 +219,8 @@ class FileSource:
             elif checkIfXmlIsEis:
                 try:
                     assert self.cntlr is not None
-                    _filename = self.cntlr.webCache.getfilename(self.url)
+                    _filename = self.cntlr.webCache.getfilename(
+                        self.cntlr.modelManager.disclosureSystem.mappedUrl(self.url))
                     assert _filename is not None
                     file = open(_filename, errors='replace')
                     l = file.read(256) # may have comments before first element
@@ -233,7 +241,8 @@ class FileSource:
         if self.isValid and not self.isOpen:
             if (self.isZip or self.isTarGz or self.isEis or self.isXfd or self.isRss or self.isInstalledTaxonomyPackage) and self.cntlr:
                 assert isinstance(self.url, str)
-                self.basefile = self.cntlr.webCache.getfilename(self.url, reload=reloadCache)
+                self.basefile = self.cntlr.webCache.getfilename(
+                    self.cntlr.modelManager.disclosureSystem.mappedUrl(self.url), reload=reloadCache)
             else:
                 self.basefile = self.url
             self.baseurl = self.url # url gets changed by selection
@@ -265,8 +274,7 @@ class FileSource:
                     assert isinstance(self.basefile, str)
                     file: io.BufferedReader | io.BytesIO | io.StringIO | None = open(self.basefile, 'rb')
                     assert isinstance(file, (io.BufferedReader, io.BytesIO))
-                    more = True
-                    while more:
+                    while True:
                         l = file.read(8)
                         if len(l) < 8:
                             break
@@ -384,7 +392,7 @@ class FileSource:
                 assert self.taxonomyPackage is not None
                 self.mappedPaths = cast('dict[str, str]', self.taxonomyPackage.get("remappings"))
 
-    def openZipStream(self, sourceZipStream: str) -> None:
+    def openZipStream(self, sourceZipStream: BinaryIO) -> None:
         if not self.isOpen:
             assert isinstance(self.url, str)
             self.basefile = self.url
@@ -446,7 +454,7 @@ class FileSource:
     def reportPackage(self) -> ReportPackage | None:
         try:
             self._reportPackage: ReportPackage | None
-            return self._reportPackage
+            return cast(Optional[ReportPackage], self._reportPackage)
         except AttributeError:
             self._reportPackage = ReportPackage.fromFileSource(self)
             return self._reportPackage
@@ -472,8 +480,11 @@ class FileSource:
 
     def isMappedUrl(self, url: str) -> bool:
         if self.mappedPaths is not None:
-            return any(url.startswith(mapFrom)
-                       for mapFrom in self.mappedPaths)
+            if any(url.startswith(mapFrom)
+                       for mapFrom in self.mappedPaths):
+                return True
+        if self.cntlr and self.cntlr.modelManager.disclosureSystem.isMappedUrl(url):
+            return True
         return False
 
     def mappedUrl(self, url: str) -> str:
@@ -482,6 +493,8 @@ class FileSource:
                 if url.startswith(mapFrom):
                     url = mapTo + url[len(mapFrom):]
                     break
+        if self.cntlr:
+            return self.cntlr.modelManager.disclosureSystem.mappedUrl(url)
         return url
 
     def fileSourceContainingFilepath(self, filepath: str | None) -> FileSource | None:
@@ -644,6 +657,30 @@ class FileSource:
         else:
             return openXmlFileStream(self.cntlr, filepath, stripDeclaration)
 
+    def getBytesSize(self) -> int | None:
+        """
+        Get the size of the zip file in bytes.
+        :return: Size of the zip file in bytes, or None if not applicable.
+        """
+        if isinstance(self.basefile, str) and os.path.isfile(self.basefile):
+            return os.path.getsize(self.basefile)
+        # ZipFile.fp is a private field, but is currently the simplest way for us to
+        # access the internal stream
+        if isinstance(self.fs, zipfile.ZipFile) and (fp := getattr(self.fs, 'fp')) is not None:
+            stream = cast(IO[Any], fp)
+            stream.seek(0, 2)  # Move to the end of the file
+            return stream.tell()  # Report the current position, which is the size of the file
+        return None
+
+    def getBytesSizeEstimate(self) -> int | None:
+        """
+        Get an estimated size of the zip file in bytes.
+        :return: Estimated size of the zip file in bytes, or None if not applicable.
+        """
+        if not isinstance(self.fs, zipfile.ZipFile):
+            return None
+        return sum(zi.compress_size for zi in self.fs.infolist())
+
     def exists(self, filepath: str) -> bool:
         archiveFileSource = self.fileSourceContainingFilepath(filepath)
         if archiveFileSource is not None:
@@ -769,7 +806,7 @@ class FileSource:
 
     def basedUrl(self, selection: str) -> str:
         baseurl = getattr(self, "baseurl", None)
-        if not baseurl or isHttpUrl(selection) or os.path.isabs(selection):
+        if not baseurl or isHttpUrl(selection) or isLegacyAbs(selection):
             return selection
         assert isinstance(baseurl, str)
         if self.baseIsHttp or os.sep == '/':
@@ -806,11 +843,12 @@ def openFileStream(
             cntlr
             and hasattr(cntlr, "modelManager")
         ): # may be called early in initialization for PluginManager
-        filepath = cntlr.modelManager.disclosureSystem.mappedUrl(filepath)  # type: ignore[no-untyped-call]
+        filepath = cntlr.modelManager.disclosureSystem.mappedUrl(filepath)
     if archiveFilenameParts(filepath): # file is in an archive
         return openFileSource(filepath, cntlr).file(filepath, binary='b' in mode, encoding=encoding)[0]
     if isHttpUrl(filepath) and cntlr:
-        _cacheFilepath = cntlr.webCache.getfilename(filepath, normalize=True) # normalize is separate step in ModelDocument retrieval, combined here
+        _cacheFilepath = cntlr.webCache.getfilename(
+            cntlr.modelManager.disclosureSystem.mappedUrl(filepath), normalize=True) # normalize is separate step in ModelDocument retrieval, combined here
         if _cacheFilepath is None:
             raise OSError(_("Unable to open file: {0}.").format(filepath))
         filepath = _cacheFilepath
