@@ -158,7 +158,7 @@ class ModelTestcaseVariation(ModelObject):
         except AttributeError:
             self._dataUris = defaultdict(list) # may contain instances, schemas, linkbases
             for dataElement in XmlUtil.descendants(self, None, ("data", "input")):
-                for elt in XmlUtil.descendants(dataElement, None, ("xsd", "schema", "linkbase", "instance")):
+                for elt in XmlUtil.descendants(dataElement, None, ("xsd", "schema", "linkbase", "instance", "taxonomyPackage")):
                     self._dataUris["schema" if elt.localName == "xsd" else elt.localName].append(elt.textValue.strip())
             return self._dataUris
 
@@ -319,9 +319,15 @@ class ModelTestcaseVariation(ModelObject):
         errorElements = XmlUtil.descendants(self, None, "error")
         resultElement = XmlUtil.descendant(self, None, "result")
         if isinstance(errorElements,list) and len(errorElements) > 0:
-            return [ModelValue.qname(e, e.stringValue) if not e.get("nonStandardErrorCodes")
-                    else e.stringValue
-                    for e in errorElements]
+            errorCodes = []
+            for errorElement in errorElements:
+                if errorElement.get("nonStandardErrorCodes"):
+                    errorCode = errorElement.stringValue
+                else:
+                    errorCode = ModelValue.qname(errorElement, errorElement.stringValue)
+                num = int(errorElement.attr("num") or 1)
+                errorCodes.extend([errorCode] * num)
+            return errorCodes
         #else:
         #    errorElement = errorElements[1]
         #    if errorElement is not None and not errorElement.get("nonStandardErrorCodes"):
@@ -353,6 +359,13 @@ class ModelTestcaseVariation(ModelObject):
 
         return None
 
+    @property
+    def expectedWarnings(self):
+        warningElements = XmlUtil.descendants(self, None, "warning")
+        if isinstance(warningElements, list) and len(warningElements) > 0:
+            return [w.stringValue for w in warningElements]
+        return None
+
     @property
     def match(self) -> str | None:
         resultElement = XmlUtil.descendant(self, None, "result")
