@@ -21,10 +21,19 @@ from urllib import request as proxyhandlers
 
 import certifi
 
+from arelle.PythonUtil import isLegacyAbs
+
 try:
     import ssl
 except ImportError:
     ssl = None
+
+try:
+    import truststore
+except ImportError:
+    # truststore requires Python > 3.9
+    truststore = None
+
 from arelle.FileSource import SERVER_WEB_CACHE, archiveFilenameParts
 from arelle.PluginManager import pluginClassMethods
 from arelle.UrlUtil import isHttpUrl
@@ -265,12 +274,10 @@ class WebCache:
             self.http_auth_handler = proxyhandlers.HTTPBasicAuthHandler()
             proxyHandlers = [self.proxy_handler, self.proxy_auth_handler, self.http_auth_handler]
         if ssl:
-            # Attempts to load the default CA certificates from the OS.
-            context = ssl.create_default_context()
+            # Attempt to load the default CA certificates from the OS using truststore if available, else fallback to OpenSSL's default context.
+            context = truststore.SSLContext(ssl.PROTOCOL_TLS_CLIENT) if truststore else ssl.create_default_context()
             # Include certifi certificates (Mozilla’s carefully curated
-            # collection) for systems with outdated certs and for platforms
-            # that we're unable to load certs from (macOS and some Linux
-            # distros.)
+            # collection) for systems with outdated certs.
             context.load_verify_locations(cafile=certifi.where())
             if self.noCertificateCheck:  # this is required in some Akamai environments, such as sec.gov
                 context.check_hostname = False
@@ -315,7 +322,7 @@ class WebCache:
         if url:
             if url.startswith("file://"): url = url[7:]
             elif url.startswith("file:\\"): url = url[6:]
-        if url and not (isHttpUrl(url) or os.path.isabs(url)):
+        if url and not (isHttpUrl(url) or isLegacyAbs(url)):
             if base is not None and not isHttpUrl(base) and '%' in url:
                 url = unquote(url)
             if base:
@@ -332,7 +339,7 @@ class WebCache:
             elif normedPath.startswith("file:\\"): normedPath = normedPath[6:]
 
             # no base, not normalized, must be relative to current working directory
-            if base is None and not os.path.isabs(url):
+            if base is None and not isLegacyAbs(url):
                 normedPath = os.path.abspath(normedPath)
         else:
             normedPath = url
@@ -455,7 +462,13 @@ class WebCache:
     def getfilename(
             self, url: str | None, base: str | None = None,
             reload: bool = False, checkModifiedTime: bool = False,
-            normalize: bool = False, filenameOnly: bool = False) -> str | None:
+            normalize: bool = False, filenameOnly: bool = False,
+            allowTransformation: bool = True) -> str | None:
+        if allowTransformation:
+            for pluginXbrlMethod in pluginClassMethods("WebCache.TransformURL"):
+                url, final = pluginXbrlMethod(self.cntlr, url, base)
+                if final:
+                    return url
         if url is None:
             return url
         if base is not None or normalize:
