@@ -20,20 +20,28 @@ _: TypeGetText
 _tuple = tuple  # type: ignore[type-arg]
 
 xsd = "http://www.w3.org/2001/XMLSchema"
+qnXsdComplexType = qname("{http://www.w3.org/2001/XMLSchema}xsd:complexType")
+qnXsdDocumentation = qname("{http://www.w3.org/2001/XMLSchema}xsd:documentation")
+qnXsdImport = qname("{http://www.w3.org/2001/XMLSchema}xsd:import")
 qnXsdSchema = qname("{http://www.w3.org/2001/XMLSchema}xsd:schema")
 qnXsdAppinfo = qname("{http://www.w3.org/2001/XMLSchema}xsd:appinfo")
 qnXsdDefaultType = qname("{http://www.w3.org/2001/XMLSchema}xsd:anyType")
 xsi = "http://www.w3.org/2001/XMLSchema-instance"
 qnXsiNil = qname(xsi, "xsi:nil")  # need default prefix in qname
+qnXsiType = qname(xsi, "xsi:type")
+qnXsiSchemaLocation = qname(xsi, "xsi:schemaLocation")
+qnXsiNoNamespaceSchemaLocation = qname(xsi, "xsi:noNamespaceSchemaLocation")
 qnXmlLang = qname("{http://www.w3.org/XML/1998/namespace}xml:lang")
 builtinAttributes = {
     qnXsiNil,
-    qname(xsi, "xsi:type"),
-    qname(xsi, "xsi:schemaLocation"),
-    qname(xsi, "xsi:noNamespaceSchemaLocation"),
+    qnXsiType,
+    qnXsiSchemaLocation,
+    qnXsiNoNamespaceSchemaLocation,
 }
 xml = "http://www.w3.org/XML/1998/namespace"
 xbrli = "http://www.xbrl.org/2003/instance"
+xhtmlBaseIdentifier = "{http://www.w3.org/1999/xhtml}base"
+xmlBaseIdentifier = "{http://www.w3.org/XML/1998/namespace}base"
 eurofilingModelNamespace = "http://www.eurofiling.info/xbrl/ext/model"
 eurofilingModelPrefix = "model"
 qnNsmap = qname("nsmap")  # artificial parent for insertion of xmlns in saving xml documents
@@ -99,6 +107,7 @@ elementLabel = "http://xbrl.org/arcrole/2008/element-label"
 genLabel = "http://xbrl.org/2008/label"
 qnGenLabel = qname("{http://xbrl.org/2008/label}label")
 xbrldt = "http://xbrl.org/2005/xbrldt"
+qnXbrldtClosed = qname("{http://xbrl.org/2005/xbrldt}xbrldt:closed")
 qnXbrldtHypercubeItem = qname("{http://xbrl.org/2005/xbrldt}xbrldt:hypercubeItem")
 qnXbrldtDimensionItem = qname("{http://xbrl.org/2005/xbrldt}xbrldt:dimensionItem")
 qnXbrldtContextElement = qname("{http://xbrl.org/2005/xbrldt}xbrldt:contextElement")
@@ -106,6 +115,12 @@ xbrldi = "http://xbrl.org/2006/xbrldi"
 qnXbrldiExplicitMember = qname("{http://xbrl.org/2006/xbrldi}xbrldi:explicitMember")
 qnXbrldiTypedMember = qname("{http://xbrl.org/2006/xbrldi}xbrldi:typedMember")
 xlink = "http://www.w3.org/1999/xlink"
+qnXlinkArcRole = qname("{http://www.w3.org/1999/xlink}xlink:arcrole")
+qnXlinkFrom = qname("{http://www.w3.org/1999/xlink}xlink:from")
+qnXlinkHref = qname("{http://www.w3.org/1999/xlink}xlink:href")
+qnXlinkLabel = qname("{http://www.w3.org/1999/xlink}xlink:label")
+qnXlinkTo = qname("{http://www.w3.org/1999/xlink}xlink:to")
+qnXlinkType = qname("{http://www.w3.org/1999/xlink}xlink:type")
 xl = "http://www.xbrl.org/2003/XLink"
 qnXlExtended = qname("{http://www.xbrl.org/2003/XLink}xl:extended")
 qnXlLocator = qname("{http://www.xbrl.org/2003/XLink}xl:locator")
@@ -825,6 +840,24 @@ def isNumericRole(role: str) -> bool:
     }
 
 
+standardDimensionArcroles = frozenset({
+    all,
+    notAll,
+    hypercubeDimension,
+    dimensionDomain,
+    domainMember,
+    dimensionDefault,
+})
+
+
+standardDefinitionArcroles = frozenset(standardDimensionArcroles | {
+    essenceAlias,
+    generalSpecial,
+    requiresElement,
+    similarTuples,
+})
+
+
 def isStandardArcrole(role: str) -> bool:
     return role in {
         "http://www.w3.org/1999/xlink/properties/linkbase",
