@@ -10,7 +10,9 @@ from arelle.ModelXbrl import ModelXbrl
 from arelle.ValidateXbrl import ValidateXbrl
 from arelle.typing import TypeGetText
 from arelle.utils.validate.ValidationPlugin import ValidationPlugin
-from .DisclosureSystems import DISCLOSURE_SYSTEM_NT16, DISCLOSURE_SYSTEM_NT17, DISCLOSURE_SYSTEM_NT18, DISCLOSURE_SYSTEM_NT19
+from .DisclosureSystems import (DISCLOSURE_SYSTEM_NT16, DISCLOSURE_SYSTEM_NT17, DISCLOSURE_SYSTEM_NT18,
+                                DISCLOSURE_SYSTEM_NT19, DISCLOSURE_SYSTEM_NL_INLINE_2024,
+                                DISCLOSURE_SYSTEM_NL_INLINE_2024_GAAP_OTHER)
 from .PluginValidationDataExtension import PluginValidationDataExtension
 
 _: TypeGetText
@@ -20,9 +22,11 @@ class ValidationPluginExtension(ValidationPlugin):
     def newPluginData(self, validateXbrl: ValidateXbrl) -> PluginValidationDataExtension:
         disclosureSystem = validateXbrl.disclosureSystem.name
         if disclosureSystem == DISCLOSURE_SYSTEM_NT16:
+            ifrsNamespace = None
             jenvNamespace = 'http://www.nltaxonomie.nl/nt16/jenv/20211208/dictionary/jenv-bw2-data'
             kvkINamespace = 'http://www.nltaxonomie.nl/nt16/kvk/20211208/dictionary/kvk-data'
             nlTypesNamespace = 'http://www.nltaxonomie.nl/nt16/sbr/20210301/dictionary/nl-types'
+            rjNamespace = None
             entrypointRoot = 'http://www.nltaxonomie.nl/nt16/kvk/20211208/entrypoints/'
             entrypoints = {entrypointRoot + e for e in [
                 'kvk-rpt-jaarverantwoording-2021-ifrs-full.xsd',
@@ -56,9 +60,11 @@ class ValidationPluginExtension(ValidationPlugin):
                 'kvk-rpt-jaarverantwoording-2021-nlgaap-zorginstellingen.xsd',
             ]}
         elif disclosureSystem == DISCLOSURE_SYSTEM_NT17:
+            ifrsNamespace = None
             jenvNamespace = 'http://www.nltaxonomie.nl/nt17/jenv/20221214/dictionary/jenv-bw2-data'
             kvkINamespace = 'http://www.nltaxonomie.nl/nt17/kvk/20221214/dictionary/kvk-data'
             nlTypesNamespace = 'http://www.nltaxonomie.nl/nt17/sbr/20220301/dictionary/nl-types'
+            rjNamespace = None
             entrypointRoot = 'http://www.nltaxonomie.nl/nt17/kvk/20221214/entrypoints/'
             entrypoints = {entrypointRoot + e for e in [
                 'kvk-rpt-jaarverantwoording-2022-ifrs-full.xsd',
@@ -93,9 +99,11 @@ class ValidationPluginExtension(ValidationPlugin):
                 'kvk-rpt-jaarverantwoording-2022-nlgaap-zorginstellingen.xsd',
             ]}
         elif disclosureSystem == DISCLOSURE_SYSTEM_NT18:
+            ifrsNamespace = None
             jenvNamespace = 'http://www.nltaxonomie.nl/nt18/jenv/20231213/dictionary/jenv-bw2-data'
             kvkINamespace = 'http://www.nltaxonomie.nl/nt18/kvk/20231213/dictionary/kvk-data'
             nlTypesNamespace = 'http://www.nltaxonomie.nl/nt18/sbr/20230301/dictionary/nl-types'
+            rjNamespace = None
             entrypointRoot = 'http://www.nltaxonomie.nl/nt18/kvk/20231213/entrypoints/'
             entrypoints = {entrypointRoot + e for e in [
                 'kvk-rpt-jaarverantwoording-2023-ifrs-full.xsd',
@@ -130,9 +138,11 @@ class ValidationPluginExtension(ValidationPlugin):
                 'kvk-rpt-jaarverantwoording-2023-nlgaap-zorginstellingen.xsd',
             ]}
         elif disclosureSystem == DISCLOSURE_SYSTEM_NT19:
+            ifrsNamespace = None
             jenvNamespace = 'http://www.nltaxonomie.nl/nt19/jenv/20241211/dictionary/jenv-bw2-data'
             kvkINamespace = 'http://www.nltaxonomie.nl/nt19/kvk/20241211/dictionary/kvk-data'
             nlTypesNamespace = 'http://www.nltaxonomie.nl/nt19/sbr/20240301/dictionary/nl-types'
+            rjNamespace = None
             entrypointRoot = 'http://www.nltaxonomie.nl/nt19/kvk/20241211/entrypoints/'
             entrypoints = {entrypointRoot + e for e in [
                 'kvk-rpt-jaarverantwoording-2024-ifrs-full.xsd',
@@ -166,20 +176,60 @@ class ValidationPluginExtension(ValidationPlugin):
                 'kvk-rpt-jaarverantwoording-2024-nlgaap-verzekeringsmaatschappijen.xsd',
                 'kvk-rpt-jaarverantwoording-2024-nlgaap-zorginstellingen.xsd',
             ]}
+        elif disclosureSystem == DISCLOSURE_SYSTEM_NL_INLINE_2024:
+            ifrsNamespace = 'https://xbrl.ifrs.org/taxonomy/2024-03-27/ifrs-full'
+            jenvNamespace = 'https://www.nltaxonomie.nl/bw2-titel9/2024-12-31/bw2-titel9-cor'
+            kvkINamespace = 'https://www.nltaxonomie.nl/kvk/2024-12-31/kvk-cor'
+            nlTypesNamespace = None
+            rjNamespace = 'https://www.nltaxonomie.nl/rj/2024-12-31/rj-cor'
+            entrypointRoot = 'http://www.nltaxonomie.nl/kvk/2024-12-31/'
+            entrypoints = {entrypointRoot + e for e in [
+                'kvk-annual-report-ifrs-ext.xsd',
+                'kvk-annual-report-nlgaap-ext.xsd',
+            ]}
+        elif disclosureSystem == DISCLOSURE_SYSTEM_NL_INLINE_2024_GAAP_OTHER:
+            ifrsNamespace = 'https://xbrl.ifrs.org/taxonomy/2024-03-27/ifrs-full'
+            jenvNamespace = 'https://www.nltaxonomie.nl/bw2-titel9/2024-12-31/bw2-titel9-cor'
+            kvkINamespace = 'https://www.nltaxonomie.nl/kvk/2024-12-31/kvk-cor'
+            nlTypesNamespace = None
+            rjNamespace =  'https://www.nltaxonomie.nl/rj/2024-12-31/rj-cor'
+            entrypointRoot = 'http://www.nltaxonomie.nl/kvk/2024-12-31/'
+            entrypoints = {entrypointRoot + e for e in [
+                'kvk-annual-report-other-gaap.xsd',
+            ]}
         else:
             raise ValueError(f'Invalid NL disclosure system: {disclosureSystem}')
         return PluginValidationDataExtension(
             self.name,
-            financialReportingPeriodCurrentStartDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodCurrentStartDate'),
-            financialReportingPeriodCurrentEndDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodCurrentEndDate'),
-            financialReportingPeriodPreviousStartDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodPreviousStartDate'),
-            financialReportingPeriodPreviousEndDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodPreviousEndDate'),
-            formattedExplanationItemTypeQn=qname(f'{{{nlTypesNamespace}}}formattedExplanationItemType'),
+            chamberOfCommerceRegistrationNumberQn=qname(f'{{{jenvNamespace}}}ChamberOfCommerceRegistrationNumber'),
             documentAdoptionDateQn=qname(f'{{{jenvNamespace}}}DocumentAdoptionDate'),
             documentAdoptionStatusQn=qname(f'{{{jenvNamespace}}}DocumentAdoptionStatus'),
             documentResubmissionUnsurmountableInaccuraciesQn=qname(f'{{{kvkINamespace}}}DocumentResubmissionDueToUnsurmountableInaccuracies'),
             entrypointRoot=entrypointRoot,
             entrypoints=entrypoints,
+            financialReportingPeriodQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriod'),
+            financialReportingPeriodCurrentStartDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodCurrentStartDate'),
+            financialReportingPeriodCurrentEndDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodCurrentEndDate'),
+            financialReportingPeriodPreviousStartDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodPreviousStartDate'),
+            financialReportingPeriodPreviousEndDateQn=qname(f'{{{jenvNamespace}}}FinancialReportingPeriodPreviousEndDate'),
+            formattedExplanationItemTypeQn=qname(f'{{{nlTypesNamespace}}}formattedExplanationItemType'),
+            ifrsIdentifier = 'https://xbrl.ifrs.org',
+            permissibleGAAPRootAbstracts=frozenset([
+                qname(f'{{{jenvNamespace}}}BalanceSheetTitle'),
+                qname(f'{{{jenvNamespace}}}IncomeStatementTitle'),
+                qname(f'{{{jenvNamespace}}}StatementOfComprehensiveIncomeTitle'),
+                qname(f'{{{jenvNamespace}}}EquityStatementOfChangesTitle'),
+                qname(f'{{{kvkINamespace}}}AnnualReportFilingInformationTitle'),
+                qname(f'{{{rjNamespace}}}StatementOfCashFlowsTitle'),
+            ]),
+            permissibleIFRSRootAbstracts=frozenset([
+                qname(f'{{{ifrsNamespace}}}StatementOfFinancialPositionAbstract'),
+                qname(f'{{{ifrsNamespace}}}IncomeStatementAbstract'),
+                qname(f'{{{ifrsNamespace}}}StatementOfComprehensiveIncomeAbstract'),
+                qname(f'{{{ifrsNamespace}}}StatementOfCashFlowsAbstract'),
+                qname(f'{{{ifrsNamespace}}}StatementOfChangesInEquityAbstract'),
+                qname(f'{{{kvkINamespace}}}AnnualReportFilingInformationTitle'),
+            ]),
             textFormattingSchemaPath='sbr-text-formatting.xsd',
             textFormattingWrapper='<formattedText xmlns="http://www.nltaxonomie.nl/2017/xbrl/sbr-text-formatting">{}</formattedText>',
         )
@@ -187,7 +237,7 @@ class ValidationPluginExtension(ValidationPlugin):
     def modelXbrlLoadComplete(self, modelXbrl: ModelXbrl, *args: Any, **kwargs: Any) -> ModelDocument | LoadingException | None:
         if self.disclosureSystemFromPluginSelected(modelXbrl):
             disclosureSystem = modelXbrl.modelManager.disclosureSystem.name
-            if disclosureSystem in (DISCLOSURE_SYSTEM_NT16, DISCLOSURE_SYSTEM_NT17, DISCLOSURE_SYSTEM_NT18, DISCLOSURE_SYSTEM_NT19):
+            if disclosureSystem in (DISCLOSURE_SYSTEM_NT16, DISCLOSURE_SYSTEM_NT17, DISCLOSURE_SYSTEM_NT18, DISCLOSURE_SYSTEM_NT19, DISCLOSURE_SYSTEM_NL_INLINE_2024):
                 # Dutch taxonomies prior to 2025 incorrectly used hypercube linkrole for roots instead of dimension linkrole.
                 paramQName = qname('tlbDimRelsUseHcRoleForDomainRoots', noPrefixIsNoNamespace=True)
                 modelXbrl.modelManager.formulaOptions.parameterValues[paramQName] = (None, "true")
