@@ -125,4 +125,47 @@ NL_PACKAGES: dict[str, list[ConformanceSuiteAssetConfig]] = {
         ),
         NL_BASE,
     ],
+    'NL-INLINE-2024': [
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('kvk-2024_taxonomie.zip'),
+            public_download_url='https://www.sbr-nl.nl/sites/default/files/2025-01/kvk-2024_taxonomie.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('rj-2024_taxonomie.zip'),
+            public_download_url='https://www.sbr-nl.nl/sites/default/files/2025-01/rj-2024_taxonomie.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('bw2-titel9_taxonomie.zip'),
+            public_download_url='https://www.sbr-nl.nl/sites/default/files/2025-01/bw2-titel9_taxonomie.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('ncgc-2022_taxonomie.zip'),
+            public_download_url='https://www.sbr-nl.nl/sites/default/files/2025-01/ncgc-2022_taxonomie.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('ifrs-2024_taxonomie.zip'),
+            public_download_url='https://www.sbr-nl.nl/sites/default/files/2025-01/ifrs-2024_taxonomie.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('wnt-2024_taxonomie.zip'),
+            public_download_url='https://www.sbr-nl.nl/sites/default/files/2025-01/wnt-2024_taxonomie.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('IFRSAT-2024-03-27_29.08.24.zip'),
+            public_download_url='https://www.ifrs.org/content/dam/ifrs/standards/taxonomy/ifrs-taxonomies/IFRSAT-2024-03-27_29.08.24.zip',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('KVK_taxonomie_2024_draft.zip'),
+            public_download_url='',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('JenV_taxonomie_2024_draft.zip'),
+            public_download_url='',
+        ),
+        ConformanceSuiteAssetConfig.public_taxonomy_package(
+            Path('RJ_taxonomie_2024_draft.zip'),
+            public_download_url='',
+        ),
+        LEI_2020_07_02,
+    ],
 }
