@@ -4,6 +4,7 @@ from tests.integration_tests.validation.conformance_suite_config import Conforma
 from tests.integration_tests.validation.conformance_suite_configurations.cipc_current import config as cipc_current
 from tests.integration_tests.validation.conformance_suite_configurations.dba_current import config as dba_current
 from tests.integration_tests.validation.conformance_suite_configurations.dba_multi_current import config as dba_multi_current
+from tests.integration_tests.validation.conformance_suite_configurations.edinet import config as edinet
 from tests.integration_tests.validation.conformance_suite_configurations.efm_current import config as efm_current
 from tests.integration_tests.validation.conformance_suite_configurations.efm_reg_dqc import config as efm_reg_dqc
 from tests.integration_tests.validation.conformance_suite_configurations.efm_reg_pragmatic import config as efm_reg_pragmatic
@@ -24,6 +25,8 @@ from tests.integration_tests.validation.conformance_suite_configurations.nl_nt16
 from tests.integration_tests.validation.conformance_suite_configurations.nl_nt17 import config as nl_nt17
 from tests.integration_tests.validation.conformance_suite_configurations.nl_nt18 import config as nl_nt18
 from tests.integration_tests.validation.conformance_suite_configurations.nl_nt19 import config as nl_nt19
+from tests.integration_tests.validation.conformance_suite_configurations.nl_inline_2024 import config as nl_inline_2024
+from tests.integration_tests.validation.conformance_suite_configurations.nl_inline_2024_gaap_other import config as nl_inline_2024_gaap_other
 from tests.integration_tests.validation.conformance_suite_configurations.ros_current import config as ros_current
 from tests.integration_tests.validation.conformance_suite_configurations.xbrl_2_1 import config as xbrl_2_1
 from tests.integration_tests.validation.conformance_suite_configurations.xbrl_calculations_1_1 import config as xbrl_calculations_1_1
@@ -52,6 +55,7 @@ ALL_CONFORMANCE_SUITE_CONFIGS: tuple[ConformanceSuiteConfig, ...] = (
     cipc_current,
     dba_current,
     dba_multi_current,
+    edinet,
     efm_current,
     efm_reg_dqc,
     efm_reg_pragmatic,
@@ -72,6 +76,8 @@ ALL_CONFORMANCE_SUITE_CONFIGS: tuple[ConformanceSuiteConfig, ...] = (
     nl_nt17,
     nl_nt18,
     nl_nt19,
+    nl_inline_2024,
+    nl_inline_2024_gaap_other,
     ros_current,
     xbrl_2_1,
     xbrl_calculations_1_1,
