@@ -8,9 +8,6 @@ config = ConformanceSuiteConfig(
             entry_point=Path('data-type-registry-1.11.0-REC+registry+2024-01-31/conf/dtr/testcase-index.xml'),
         ),
     ],
-    args=[
-        '--formula', 'run',
-    ],
     info_url='https://gitlab.xbrl.org/base-spec/data-type-registry/-/tree/1.11.0-REC+registry+2024-01-31/conf',
     membership_url='https://www.xbrl.org/join',
     name=PurePath(__file__).stem,
