@@ -1,6 +1,10 @@
 import re
-from pathlib import PurePath, Path
-from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig, ConformanceSuiteAssetConfig
+from pathlib import Path, PurePath
+
+from tests.integration_tests.validation.conformance_suite_config import (
+    ConformanceSuiteAssetConfig,
+    ConformanceSuiteConfig,
+)
 
 config = ConformanceSuiteConfig(
     args=[
