@@ -11,15 +11,16 @@ from .conformance_suite_configurations.xbrl_2_1 import config as xbrl_2_1
 
 
 LINUX = 'ubuntu-24.04'
-MACOS = 'macos-14'
+MACOS = 'macos-15'
 WINDOWS = 'windows-2022'
 ALL_PYTHON_VERSIONS = (
     '3.9',
     '3.10',
     '3.11',
     '3.12',
+    '3.13.5',
 )
-LATEST_PYTHON_VERSION = '3.12'
+LATEST_PYTHON_VERSION = '3.13.5'
 # number of cores on the runners
 # https://docs.github.com/en/actions/using-github-hosted-runners/about-github-hosted-runners/about-github-hosted-runners#supported-runners-and-hardware-resources
 OS_CORES = {
